@@ -2,9 +2,9 @@ import argparse
 import os
 import subprocess
 from pathlib import Path
+from platform import python_version
 from shutil import which
 
-from platform import python_version
 from py3status.version import version
 
 
@@ -19,7 +19,7 @@ def parse_cli_args():
 
     # get window manager
     with Path(os.devnull).open("w") as devnull:
-        if subprocess.call(["pgrep", "i3"], stdout=devnull) == 0:
+        if subprocess.call(["pgrep", "-x", "i3"], stdout=devnull) == 0:
             wm = "i3"
         else:
             wm = "sway"
@@ -88,13 +88,6 @@ def parse_cli_args():
         action="store_true",
         help="enable debug logging in syslog or log file if --log-file option is passed",
     )
-    parser.add_argument(
-        "-g",
-        "--gevent",
-        action="store_true",
-        dest="gevent",
-        help="enable gevent monkey patching",
-    )
     parser.add_argument(
         "-i",
         "--include",
