@@ -1,5 +1,4 @@
-# -*- coding: utf-8 -*-
-"""
+r"""
 Display NVIDIA properties currently exhibiting in the NVIDIA GPUs.
 
 nvidia-smi, short for NVIDIA System Management Interface program, is a cross
@@ -79,15 +78,14 @@ STRING_NOT_INSTALLED = "not installed"
 
 
 class Py3status:
-    """
-    """
+    """ """
 
     # available configuration parameters
     cache_timeout = 10
     format = "{format_gpu}"
     format_gpu = (
-        u"{gpu_name} [\?color=temperature.gpu {temperature.gpu}°C] "
-        "[\?color=memory.used_percent {memory.used_percent}%]"
+        r"{gpu_name} [\?color=temperature.gpu {temperature.gpu}°C] "
+        r"[\?color=memory.used_percent {memory.used_percent}%]"
     )
     format_gpu_separator = " "
     memory_unit = None
@@ -100,12 +98,10 @@ class Py3status:
 
         properties = self.py3.get_placeholders_list(self.format_gpu)
         format_gpu = {x: ":.1f" for x in properties if "used_percent" in x}
-        self.format_gpu = self.py3.update_placeholder_formats(
-            self.format_gpu, format_gpu
-        )
+        self.format_gpu = self.py3.update_placeholder_formats(self.format_gpu, format_gpu)
 
         new_memory_properties = set()
-        new_properties = set(["memory.used", "memory.total"])
+        new_properties = {"memory.used", "memory.total"}
         for name in properties:
             if "used_percent" in name:
                 continue
@@ -132,11 +128,11 @@ class Py3status:
         for line in nvidia_data.splitlines():
             gpu = dict(zip(self.properties, line.split(", ")))
             gpu["memory.used_percent"] = (
-                float(gpu["memory.used"]) / float(gpu["memory.total"]) * 100.0
+                float(gpu["memory.used"]) / float(gpu["memory.total"]) * 100
             )
 
             for key in self.memory_properties:
-                value, unit_key = float(gpu[key]) * 1024 ** 2, key + "_unit"
+                value, unit_key = float(gpu[key]) * 1024**2, key + "_unit"
                 value, unit_value = self.py3.format_units(value, self.memory_unit)
                 gpu.update({key: value, unit_key: unit_value})
 
@@ -159,9 +155,9 @@ if __name__ == "__main__":
     from sys import argv
 
     if "--list-properties" in argv:
-        from sys import exit
         from json import dumps
         from subprocess import check_output
+        from sys import exit
 
         help_cmd = "nvidia-smi --help-query-gpu"
         help_data = check_output(help_cmd.split()).decode()
